Common Codes Used by Xiaowei
-------------------------------------

Python library for Xiaowei's daily work.

Example of `myopen`

    for ln in myopen('input.gz'):
        print ln

For details, please read source codes.

Contact
-------
Xiaowei Zhan<zhanxw[at]gmail.com>

